==> jc-1.4.0.tar.gz: javax/swing/FocusManager__24DisabledFocusManager.h <==
// class javax.swing.FocusManager$DisabledFocusManager

// class file dependencies
// @dep_class bd8f813050148ee1 java_awt_DefaultKeyboardFocusManager
// @dep_class 3c8264cdfd76a265 java_awt_KeyboardFocusManager
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 6d7c3f688095f3e7 javax_swing_FocusManager
// @dep_class 6b20467011448602 javax_swing_FocusManager__24DisabledFocusManager

// header file dependencies
// @dep_header javax_swing_FocusManager

#include "javax/swing/FocusManager.h"

#ifndef _JC_javax_swing_FocusManager__24DisabledFocusManager_H_
#define _JC_javax_swing_FocusManager__24DisabledFocusManager_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_awt_event_KeyEvent$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_FocusManager__24DisabledFocusManager$sub_refs	_jc_javax_swing_FocusManager__24DisabledFocusManager$sub_refs;
typedef struct _jc_javax_swing_FocusManager__24DisabledFocusManager$sub_nonrefs	_jc_javax_swing_FocusManager__24DisabledFocusManager$sub_nonrefs;
typedef struct _jc_javax_swing_FocusManager__24DisabledFocusManager$refs	_jc_javax_swing_FocusManager__24DisabledFocusManager$refs;
typedef struct _jc_javax_swing_FocusManager__24DisabledFocusManager$nonrefs	_jc_javax_swing_FocusManager__24DisabledFocusManager$nonrefs;
typedef struct _jc_javax_swing_FocusManager__24DisabledFocusManager$object	_jc_javax_swing_FocusManager__24DisabledFocusManager$object;

typedef const struct _jc_javax_swing_FocusManager__24DisabledFocusManager$vmethods	_jc_javax_swing_FocusManager__24DisabledFocusManager$vmethods;
typedef const struct _jc_javax_swing_FocusManager__24DisabledFocusManager$vtable	_jc_javax_swing_FocusManager__24DisabledFocusManager$vtable;
typedef const struct _jc_javax_swing_FocusManager__24DisabledFocusManager$vtype	_jc_javax_swing_FocusManager__24DisabledFocusManager$vtype;

// Constructors
extern void _jc_javax_swing_FocusManager__24DisabledFocusManager$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_FocusManager__24DisabledFocusManager$object *);

// Virtual methods
extern void _jc_javax_swing_FocusManager__24DisabledFocusManager$method$focusNextComponent$7bc09eefe16e9c64(_jc_env *, struct _jc_javax_swing_FocusManager__24DisabledFocusManager$object *, struct _jc_java_awt_Component$object *);
extern void _jc_javax_swing_FocusManager__24DisabledFocusManager$method$focusPreviousComponent$693af46b828c4036(_jc_env *, struct _jc_javax_swing_FocusManager__24DisabledFocusManager$object *, struct _jc_java_awt_Component$object *);
extern void _jc_javax_swing_FocusManager__24DisabledFocusManager$method$processKeyEvent$44dfe6771c38c557(_jc_env *, struct _jc_javax_swing_FocusManager__24DisabledFocusManager$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_event_KeyEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_FocusManager__24DisabledFocusManager$method_info$focusNextComponent$7bc09eefe16e9c64;
extern _jc_method _jc_javax_swing_FocusManager__24DisabledFocusManager$method_info$focusPreviousComponent$693af46b828c4036;
extern _jc_method _jc_javax_swing_FocusManager__24DisabledFocusManager$method_info$processKeyEvent$44dfe6771c38c557;

// Virtual methods structure
struct _jc_javax_swing_FocusManager__24DisabledFocusManager$vmethods {
	void	(*focusNextComponent$7bc09eefe16e9c64)(_jc_env *, struct _jc_javax_swing_FocusManager__24DisabledFocusManager$object *, struct _jc_java_awt_Component$object *);
	void	(*focusPreviousComponent$693af46b828c4036)(_jc_env *, struct _jc_javax_swing_FocusManager__24DisabledFocusManager$object *, struct _jc_java_awt_Component$object *);
	void	(*processKeyEvent$44dfe6771c38c557)(_jc_env *, struct _jc_javax_swing_FocusManager__24DisabledFocusManager$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_event_KeyEvent$object *);
};

// Vtable
struct _jc_javax_swing_FocusManager__24DisabledFocusManager$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_KeyboardFocusManager$vmethods	java_awt_KeyboardFocusManager;
	_jc_java_awt_DefaultKeyboardFocusManager$vmethods	java_awt_DefaultKeyboardFocusManager;
	_jc_javax_swing_FocusManager$vmethods	javax_swing_FocusManager;
	_jc_javax_swing_FocusManager__24DisabledFocusManager$vmethods	javax_swing_FocusManager__24DisabledFocusManager;
};

// Vtype
struct _jc_javax_swing_FocusManager__24DisabledFocusManager$vtype {
	_jc_type			type;
	_jc_javax_swing_FocusManager__24DisabledFocusManager$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_FocusManager__24DisabledFocusManager$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_FocusManager__24DisabledFocusManager$refs {
    _jc_javax_swing_FocusManager__24DisabledFocusManager$sub_refs	javax_swing_FocusManager__24DisabledFocusManager;
    _jc_javax_swing_FocusManager$sub_refs	javax_swing_FocusManager;
    _jc_java_awt_DefaultKeyboardFocusManager$sub_refs	java_awt_DefaultKeyboardFocusManager;
    _jc_java_awt_KeyboardFocusManager$sub_refs	java_awt_KeyboardFocusManager;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_FocusManager__24DisabledFocusManager$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_FocusManager__24DisabledFocusManager$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_KeyboardFocusManager$sub_nonrefs	java_awt_KeyboardFocusManager;
    _jc_java_awt_DefaultKeyboardFocusManager$sub_nonrefs	java_awt_DefaultKeyboardFocusManager;
    _jc_javax_swing_FocusManager$sub_nonrefs	javax_swing_FocusManager;
    _jc_javax_swing_FocusManager__24DisabledFocusManager$sub_nonrefs	javax_swing_FocusManager__24DisabledFocusManager;
};

// Object instance structure
struct _jc_javax_swing_FocusManager__24DisabledFocusManager$object {
	_jc_javax_swing_FocusManager__24DisabledFocusManager$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_FocusManager__24DisabledFocusManager$vtype	*vtype;
	_jc_javax_swing_FocusManager__24DisabledFocusManager$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_FocusManager__24DisabledFocusManager$vtype _jc_javax_swing_FocusManager__24DisabledFocusManager$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_FocusManager__24DisabledFocusManager, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_FocusManager__24DisabledFocusManager$class_object;

#endif	/* _JC_javax_swing_FocusManager__24DisabledFocusManager_H_ */

==> jc-1.4.5.tar.gz: javax/swing/FocusManager__24DisabledFocusManager.h <==
// class javax.swing.FocusManager$DisabledFocusManager

// class file dependencies
// @dep_class bd8f813050148ee1 java_awt_DefaultKeyboardFocusManager
// @dep_class 3c8264cdfd76a265 java_awt_KeyboardFocusManager
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 6d7c3f688095f3e7 javax_swing_FocusManager
// @dep_class 6b20467011448602 javax_swing_FocusManager__24DisabledFocusManager

// header file dependencies
// @dep_header javax_swing_FocusManager

#include "javax/swing/FocusManager.h"

#ifndef _JC_javax_swing_FocusManager__24DisabledFocusManager_H_
#define _JC_javax_swing_FocusManager__24DisabledFocusManager_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_awt_event_KeyEvent$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_FocusManager__24DisabledFocusManager$sub_refs	_jc_javax_swing_FocusManager__24DisabledFocusManager$sub_refs;
typedef struct _jc_javax_swing_FocusManager__24DisabledFocusManager$sub_nonrefs	_jc_javax_swing_FocusManager__24DisabledFocusManager$sub_nonrefs;
typedef struct _jc_javax_swing_FocusManager__24DisabledFocusManager$refs	_jc_javax_swing_FocusManager__24DisabledFocusManager$refs;
typedef struct _jc_javax_swing_FocusManager__24DisabledFocusManager$nonrefs	_jc_javax_swing_FocusManager__24DisabledFocusManager$nonrefs;
typedef struct _jc_javax_swing_FocusManager__24DisabledFocusManager$object	_jc_javax_swing_FocusManager__24DisabledFocusManager$object;

typedef const struct _jc_javax_swing_FocusManager__24DisabledFocusManager$vmethods	_jc_javax_swing_FocusManager__24DisabledFocusManager$vmethods;
typedef const struct _jc_javax_swing_FocusManager__24DisabledFocusManager$vtable	_jc_javax_swing_FocusManager__24DisabledFocusManager$vtable;
typedef const struct _jc_javax_swing_FocusManager__24DisabledFocusManager$vtype	_jc_javax_swing_FocusManager__24DisabledFocusManager$vtype;

// Constructors
extern void _jc_javax_swing_FocusManager__24DisabledFocusManager$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_FocusManager__24DisabledFocusManager$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_FocusManager__24DisabledFocusManager$method$focusNextComponent$7bc09eefe16e9c64(_jc_env *, struct _jc_javax_swing_FocusManager__24DisabledFocusManager$object *, struct _jc_java_awt_Component$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_FocusManager__24DisabledFocusManager$method$focusPreviousComponent$693af46b828c4036(_jc_env *, struct _jc_javax_swing_FocusManager__24DisabledFocusManager$object *, struct _jc_java_awt_Component$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_FocusManager__24DisabledFocusManager$method$processKeyEvent$44dfe6771c38c557(_jc_env *, struct _jc_javax_swing_FocusManager__24DisabledFocusManager$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_event_KeyEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_FocusManager__24DisabledFocusManager$method_info$focusNextComponent$7bc09eefe16e9c64;
extern _jc_method _jc_javax_swing_FocusManager__24DisabledFocusManager$method_info$focusPreviousComponent$693af46b828c4036;
extern _jc_method _jc_javax_swing_FocusManager__24DisabledFocusManager$method_info$processKeyEvent$44dfe6771c38c557;

// Virtual methods structure
struct _jc_javax_swing_FocusManager__24DisabledFocusManager$vmethods {
	void	(*focusNextComponent$7bc09eefe16e9c64)(_jc_env *, struct _jc_javax_swing_FocusManager__24DisabledFocusManager$object *, struct _jc_java_awt_Component$object *) _JC_JCNI_ATTR;
	void	(*focusPreviousComponent$693af46b828c4036)(_jc_env *, struct _jc_javax_swing_FocusManager__24DisabledFocusManager$object *, struct _jc_java_awt_Component$object *) _JC_JCNI_ATTR;
	void	(*processKeyEvent$44dfe6771c38c557)(_jc_env *, struct _jc_javax_swing_FocusManager__24DisabledFocusManager$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_event_KeyEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_FocusManager__24DisabledFocusManager$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_KeyboardFocusManager$vmethods	java_awt_KeyboardFocusManager;
	_jc_java_awt_DefaultKeyboardFocusManager$vmethods	java_awt_DefaultKeyboardFocusManager;
	_jc_javax_swing_FocusManager$vmethods	javax_swing_FocusManager;
	_jc_javax_swing_FocusManager__24DisabledFocusManager$vmethods	javax_swing_FocusManager__24DisabledFocusManager;
};

// Vtype
struct _jc_javax_swing_FocusManager__24DisabledFocusManager$vtype {
	_jc_type			type;
	_jc_javax_swing_FocusManager__24DisabledFocusManager$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_FocusManager__24DisabledFocusManager$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_FocusManager__24DisabledFocusManager$refs {
    _jc_javax_swing_FocusManager__24DisabledFocusManager$sub_refs	javax_swing_FocusManager__24DisabledFocusManager;
    _jc_javax_swing_FocusManager$sub_refs	javax_swing_FocusManager;
    _jc_java_awt_DefaultKeyboardFocusManager$sub_refs	java_awt_DefaultKeyboardFocusManager;
    _jc_java_awt_KeyboardFocusManager$sub_refs	java_awt_KeyboardFocusManager;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_FocusManager__24DisabledFocusManager$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_FocusManager__24DisabledFocusManager$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_KeyboardFocusManager$sub_nonrefs	java_awt_KeyboardFocusManager;
    _jc_java_awt_DefaultKeyboardFocusManager$sub_nonrefs	java_awt_DefaultKeyboardFocusManager;
    _jc_javax_swing_FocusManager$sub_nonrefs	javax_swing_FocusManager;
    _jc_javax_swing_FocusManager__24DisabledFocusManager$sub_nonrefs	javax_swing_FocusManager__24DisabledFocusManager;
};

// Object instance structure
struct _jc_javax_swing_FocusManager__24DisabledFocusManager$object {
	_jc_javax_swing_FocusManager__24DisabledFocusManager$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_FocusManager__24DisabledFocusManager$vtype	*vtype;
	_jc_javax_swing_FocusManager__24DisabledFocusManager$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_FocusManager__24DisabledFocusManager$vtype _jc_javax_swing_FocusManager__24DisabledFocusManager$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_FocusManager__24DisabledFocusManager, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_FocusManager__24DisabledFocusManager$class_object;

#endif	/* _JC_javax_swing_FocusManager__24DisabledFocusManager_H_ */
